==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Atnaujinimai patyrė nesėkmę.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Atnaujinimai patyrė nesėkmę: jie buvo pertraukti.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Atnaujinimai patyrė nesėkmę: DPKG klaida.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Atnaujinimai patyrė nesėkmę: trūksta vietos diske.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Atsisakyti ir paleisti iš naujo</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Atnaujinimai patyrė nesėkmę.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Atnaujinimai patyrė nesėkmę: jie buvo pertraukti.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Atnaujinimai patyrė nesėkmę: DPKG klaida.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Atnaujinimai patyrė nesėkmę: trūksta vietos diske.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Atsisakyti ir paleisti iš naujo</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
</context>
</TS>
